@@ -106,7 +106,8 @@ def get_networkctl_status(iface_name):
     data = collections.defaultdict(list)
     try:
         out = subprocess.check_output([NETWORKCTL, 'status', '--no-pager',
-                                       '--no-legend', '--', iface_name])
+                                       '--no-legend', '--lines=0', '--',
+                                       iface_name])
     except subprocess.CalledProcessError as e:
         logger.error('Failed to get interface "%s" status: %s', iface_name, e)
         return data
