@@ -158,7 +158,8 @@ def test_scripts_in_path(monkeypatch, scripts_etc, scripts_usr,
         stat = namedtuple('stat', ('st_mode st_uid st_gid st_size st_mtime '
                           'st_atime st_ctime'))
         # file exists
-        monkeypatch.setattr(os, 'stat', lambda x: stat(st_mode=33261, st_uid=0,
+        monkeypatch.setattr(os, 'stat', lambda x, follow_symlinks=False: stat(
+                                                       st_mode=33261, st_uid=0,
                                                        st_gid=0, st_size=99,
                                                        st_atime=1540220480,
                                                        st_mtime=1539272713,
@@ -178,32 +179,35 @@ def test_scripts_in_path(monkeypatch, scripts_etc, scripts_usr,
         _, _, debug = caplog.record_tuples[0]
         assert debug.endswith('does not exist; skipping')
         # file not executable
-        caplog.clear()
-        caplog.set_level(logging.ERROR)
         monkeypatch.setattr(os.path, 'exists', lambda x: True)
-        monkeypatch.setattr(os, 'stat', lambda x: stat(st_mode=33152, st_uid=0,
+        monkeypatch.setattr(os, 'stat', lambda x, follow_symlinks=False:
+                                                       stat(st_mode=33152, st_uid=0,
                                                        st_gid=0, st_size=99,
                                                        st_atime=1540220480,
                                                        st_mtime=1539272713,
                                                        st_ctime=1539272713))
         scripts_returned = networkd_dispatcher.scripts_in_path(path, subdir)
         assert scripts_returned == []
-        _, _, err = caplog.record_tuples[0]
-        assert err.startswith('Unable to execute script, check file mode: ')
         # file not owned by root
-        caplog.clear()
-        caplog.set_level(logging.ERROR)
         monkeypatch.setattr(os.path, 'exists', lambda x: True)
-        monkeypatch.setattr(os, 'stat', lambda x: stat(st_mode=33261,
-                                                       st_uid=1000,
+        monkeypatch.setattr(os, 'stat', lambda x, follow_symlinks=False: stat(
+                                                       st_mode=33261, st_uid=1000,
                                                        st_gid=1000, st_size=99,
                                                        st_atime=1540220480,
                                                        st_mtime=1539272713,
                                                        st_ctime=1539272713))
         scripts_returned = networkd_dispatcher.scripts_in_path(path, subdir)
         assert scripts_returned == []
-        _, _, err = caplog.record_tuples[0]
-        assert err.startswith('Unable to execute script, check file perms: ')
+        # file writeable by 'other'
+        monkeypatch.setattr(os.path, 'exists', lambda x: True)
+        monkeypatch.setattr(os, 'stat', lambda x, follow_symlinks=False: stat(
+                                                       st_mode=33278, st_uid=0,
+                                                       st_gid=0, st_size=99,
+                                                       st_atime=1540220480,
+                                                       st_mtime=1539272713,
+                                                       st_ctime=1539272713))
+        scripts_returned = networkd_dispatcher.scripts_in_path(path, subdir)
+        assert scripts_returned == []
 
 
 
@@ -336,7 +340,7 @@ with patch.object(networkd_dispatcher.Dispatcher, "_interface_scan",
             caplog.set_level(logging.WARNING)
             self.dp.trigger_all()
             _, _, ex = caplog.record_tuples[0]
-            assert ex == 'Error handling initial for interface 1'
+            assert ex == 'Error handling initial state for interface 1'
 
         @patch('networkd_dispatcher.Dispatcher.run_hooks_for_state')
         def test__handle_one_state(self, mock_run_hooks_for_state,
@@ -464,11 +468,11 @@ with patch.object(networkd_dispatcher.Dispatcher, "_interface_scan",
             mock_subprocess.wait.return_value = -1
             os.environ = old_environ
             caplog.clear()
+            caplog.set_level(logging.WARNING)
             self.dp.run_hooks_for_state(self.dp.ifaces_by_name['wlan0'],
                                         'routable')
-            caplog.set_level(logging.WARNING)
             _, _, warn = caplog.record_tuples[0]
-            assert not warn.startswith('Exist status')
+            assert warn.startswith('Exit status')
             # no scripts
             monkeypatch.setattr(Dispatcher, 'get_scripts_list',
                                 lambda x, y: None)
@@ -557,7 +561,8 @@ with patch.object(networkd_dispatcher.Dispatcher, "_interface_scan",
                     is None)
             mock_handle_state.assert_called_with('wlan0',
                                                  administrative_state=None,
-                                                 operational_state='routable')
+                                                 operational_state='routable',
+                                                 force=False)
             # remove ifaces (ifaces_by_name and iface_names_by_idx pop'd)
             self.dp.iface_names_by_idx = {1: 'lo', 2: 'eth0', 3: 'wlan0'}
             data = dbus.Dictionary(
@@ -572,7 +577,8 @@ with patch.object(networkd_dispatcher.Dispatcher, "_interface_scan",
                     is None)
             mock_handle_state.assert_called_with('wlan0',
                                                  administrative_state='linger',
-                                                 operational_state=None)
+                                                 operational_state=None,
+                                                 force=False)
             _, _, warn = caplog.record_tuples[1]
             assert warn == 'Unknown index 3 seen, reloading interface list'
             assert 3 not in self.dp.iface_names_by_idx.keys()
@@ -593,10 +599,27 @@ with patch.object(networkd_dispatcher.Dispatcher, "_interface_scan",
                     is None)
             mock_handle_state.assert_called_with('wlan0',
                                                  administrative_state='linger',
-                                                 operational_state=None)
+                                                 operational_state=None,
+                                                 force=False)
             _, _, err = caplog.record_tuples[1]
             assert err == 'Unable to remove interface at index 3.'
 
+        @patch.object(networkd_dispatcher.Dispatcher, "_handle_one_state")
+        @pytest.mark.parametrize(["admin_state", "oper_state", "expected"], [
+            ("failed", "off", None),
+            ("configured", "routable", None),
+            ("../../../configured", "routable", networkd_dispatcher.UnknownState),
+            ("linger", "linger", networkd_dispatcher.UnknownState),
+            ("", "", None),
+            (" configured", "foo", networkd_dispatcher.UnknownState),
+        ])
+        def test_handle_state(self, mock_handle_one_state, admin_state, oper_state, expected):
+            if expected is not None:
+                with pytest.raises(expected):
+                    self.dp.handle_state("foo", admin_state, oper_state, True)
+            else:
+                self.dp.handle_state("foo", admin_state, oper_state, True)
+                mock_handle_one_state.assert_called_with("foo", oper_state, "operational", force=True)
 
 @patch('networkd_dispatcher.main')
 def test___main__(mock_main, monkeypatch):
